import { CreateCrudOptionsProps, CreateCrudOptionsRet, AddReq, DelReq, EditReq, dict, compute } from '@fast-crud/fast-crud';
import * as api from './api';
import { dictionary } from '/@/utils/dictionary';
import { successMessage, warningMessage } from '../../../utils/message';
import { auth } from '/@/utils/authFunction';
import { ref, onMounted } from 'vue';
import { ElMessage } from 'element-plus';

/**
 *
 * @param crudExpose：index传递过来的示例
 * @param context：index传递过来的自定义参数
 * @returns
 */
export const createCrudOptions = function ({ crudExpose, context }: CreateCrudOptionsProps): CreateCrudOptionsRet {
	const pageRequest = async (query: any) => {
		return await api.GetList(query);
	};
	const editRequest = async ({ form, row }: EditReq) => {
		form.id = row.id;
		return await api.UpdateObj(form);
	};
	const delRequest = async ({ row }: DelReq) => {
		return await api.DelObj(row.id);
	};
	const addRequest = async ({ form }: AddReq) => {
		return await api.AddObj(form);
	};

/* 	// 修改分类和标签数据获取方式
	const categoryOptions = ref<Array<{value: number, label: string}>>([]);
	const tagOptions = ref<Array<{value: number, label: string}>>([]);
	
	// 获取分类数据
	const fetchCategories = async () => {
		try {
			const res = await api.GetcategoryList({page:1, limit:1000, tenant_id:1});
			if (res.code === 0 && res.data && res.data.items) {
				categoryOptions.value = res.data.items;
			}
		} catch (error) {
			console.error('获取分类数据失败', error);
		}
	};
	
	// 获取标签数据
	const fetchTags = async (categoryId?: number) => {
		try {
			const params = {
				page: 1,
				limit: 1000,
				tenant_id: 1
			};
			if (categoryId) {
				params.category_id = categoryId;
			}
			const res = await api.GetTagList(params);
			if (res.code === 0 && res.data && res.data.items) {
				tagOptions.value = res.data.items;
			}
		} catch (error) {
			console.error('获取标签数据失败', error);
		}
	}; */
	
	// 初始化时获取分类数据
/* 	onMounted(() => {
		fetchCategories();
		fetchTags();
	}); */

	// 添加批量更新标签的方法
	const batchUpdateTags = async (questionIds: number[], tagIds: number[]) => {
		try {
			const res = await api.BatchUpdateTags({
				question_ids: questionIds,
				tag_ids: tagIds,
				tenant_id: 1
			});
			if (res.code === 0) {
				successMessage('批量更新标签成功');
				// 刷新列表
				crudExpose.doRefresh();
			}
		} catch (error) {
			console.error('批量更新标签失败', error);
		}
	};

	// 添加批量更新分类的方法
	const batchUpdateCategory = async (questionIds: number[], categoryId: number) => {
		try {
			const res = await api.BatchUpdateCategory({
				question_ids: questionIds,
				category_id: categoryId,
				tenant_id: "1"
			});
			if (res.code === 0) {
				successMessage('批量更新分类成功');
				// 刷新列表
				crudExpose.doRefresh();
			}
		} catch (error) {
			console.error('批量更新分类失败', error);
		}
	};

	return {
		crudOptions: {
			request: {
				pageRequest,
				addRequest,
				editRequest,
				delRequest,
			},
			pagination: {
				show: true,
			},
			actionbar: {
				buttons: {
					add: {
						show: auth('role:Create'),
					},
					// 添加批量绑定标签按钮
					batchBindTags: {
						text: '批量绑定标签',
						type: 'primary',
						show: true,
						order: 2,
						click: () => {
							// 使用存储的选中行
							const selection = context.selectedRows || [];
							console.log('选中的行:', selection);
							
							if (!selection || selection.length === 0) {
								warningMessage('请先选择要操作的题目');
								return;
							}
							// 打开批量绑定标签对话框
							context.openBatchTagsDialog(selection);
						},
					},
					// 添加批量设置分类按钮
					batchSetCategory: {
						text: '批量设置分类',
						type: 'primary',
						show: true,
						order: 3,
						click: () => {
							// 使用存储的选中行
							const selection = context.selectedRows || [];
							console.log('选中的行:', selection);
							
							if (!selection || selection.length === 0) {
								warningMessage('请先选择要操作的题目');
								return;
							}
							// 打开批量设置分类对话框
							context.openBatchCategoryDialog(selection);
						},
					},
				},
			},
			rowHandle: {
				//固定右侧
				fixed: 'right',
				width: 259,
				buttons: {
					view: {
						show: true,
						size: 'small',
						icon:"View",
						type: 'text',
					},
					edit: {
						show: auth('role:Update'),
						size: 'small',
						icon:"Edit",
						type: 'text',
					},
					remove: {
						show: auth('role:Delete'),
						size: 'small',
						type: 'text',
						icon:"Delete",
					},
					/* permission: {
						type: 'primary',
						text: '权限配置',
						show: auth('role:Permission'),
						click: (clickContext: any): void => {
							const { row } = clickContext;
							context.RoleDrawer.handleDrawerOpen(row);
							context.RoleMenuBtn.setState([]);
							context.RoleMenuField.setState([]);
						},
					}, */
				},
			},
			form: {
				col: { span: 24 },
				labelWidth: '100px',
				wrapper: {
					is: 'el-dialog',
					width: '600px',
				},
			},
			columns: {
				_selection: {
					title: '选择',
					form: { show: false },
					column: {
						type: 'selection',
						align: 'center',
						width: 50,
						fixed: 'left',
						columnSetDisabled: true,
					},
				},
				id: {
					title: 'ID',
					column: { show: true ,width:80,},
					search: { show: false },
					form: { show: false },
				},
				question: {
					title: '题目内容',
					search: { show: true },
					column: {
						showOverflowTooltip: true, // 超出显示提示
						width: 300 ,// 固定列宽
						sortable: 'custom',
					},
					form: {
						rules: [{ required: true, message: '题目内容必填' }],
						component: {
							placeholder: '请输入题目内容',
						},
					},
				},
				/* question_type: {
					title: '问题类型',
					search: { show: true },
					type: 'dict-select',
					column: {
						minWidth: 100,
					},
					dict: dict({
						data: [
							{ value: 1, label: '专业技能' },
							{ value: 2, label: '通用能力' },
							{ value: 3, label: '个人特质' }
						]
					}),
					form: {
						rules: [{ required: true, message: '问题类型必填' }],
						component: {
							placeholder: '请选择问题类型',
						},
						helper: '选择问题的类型分类',
					},
				}, */
				question_form: {
					title: '题目形式',
					search: { show: true },
					type: 'dict-select',
					column: {
						minWidth: 100,
					},
					dict: dict({
						data: [
							{ value: 0, label: '开放问题' },
							{ value: 1, label: '单选题' },
							{ value: 2, label: '多选题' },
							{ value: 3, label: '色盲题' },
							{ value: 4, label: '得分题' }
						]
					}),
					form: {
						rules: [{ required: true, message: '题目形式必填' }],
						component: {
							placeholder: '请选择题目形式',
							onChange: ({ form }: { form: any }) => {
								// 重置相关字段
								if (form.question_form === 1) {
									// 单选题
									form.options = [{ option_text: '', is_correct: false, sort: 1 }, { option_text: '', is_correct: false, sort: 2 }];
								} else if (form.question_form === 2) {
									// 多选题
									form.options = [{ option_text: '', is_correct: false, sort: 1 }, { option_text: '', is_correct: false, sort: 2 }];
								} else if (form.question_form === 4) {
									// 心理评估题 - 初始化五个评分选项
									form.options = [
										{ option_text: '无', score: 0, sort: 1 },
										{ option_text: '轻度', score: 1, sort: 2 },
										{ option_text: '中度', score: 2, sort: 3 },
										{ option_text: '偏重', score: 3, sort: 4 },
										{ option_text: '严重', score: 4, sort: 5 }
									];
									// 初始化评分说明
									if (!form.scoring_reference) {
										form.scoring_reference = '该评分反映了症状表现的频率与严重程度。';
									}
								} else {
									// 开放问题
									form.options = [];
								}
							}
						},
						helper: '选择题目的形式：开放问题、单选题、多选题、色盲题或心理评估题',
					},
				},
				position_types: {
					title: '适用职位',
					search: { show: true },
					type: 'dict-select',
					column: {
						minWidth: 120,
					},
					dict: dict({
						getData: async () => {
							const res = await api.GetPositionList({page:1,limit:1000,tenant_id:1});
							console.log(res.data);
							return res.data || [];
						},
						label: 'title',
						value: 'id'
					}),
					form: {
						component: {
						/* 	name: 'el-select', */
							props: {
								multiple: true,
								filterable: true,
								placeholder: '请选择适用职位类型',
								/* options: [
									{ value: '0', label: '技术' },
									{ value: '1', label: '管理' },
								] */
							}
						},
						helper: '选择题目适用的职位类型，可多选'
					}
				},
				category_id: {
					title: '分类',
					search: { show: true },
					type: 'dict-select',
					column: {
						minWidth: 120,
						component: {
							// 自定义渲染组件，显示彩色标签
							// name: 'fs-component',
							render: ({ row }: { row: any }) => {
								if (!row.category || row.category.length === 0) return <span>-</span>;
								
								return (
											<el-tag
												key={row.category.id}
												type="warning"
												effect="plain"
												size="mini"
											>
												{row.category.name}
											</el-tag>
								);
							}
						}
					},
					dict: dict({
						// 使用API方式获取数据
						getData: async () => {
							const res = await api.GetcategoryList({page:1, limit:1000, tenant_id:1});
							return res.data.items;
						},
						label: 'name',
						value: 'id'
					}),
					form: {
						// rules: [{ required: true, message: '题目分类必填' }],
						component: {
							placeholder: '请选择题目分类',
							/* onChange: ({ value }: { value: number }) => {
								// 当分类变化时，重新获取对应的标签
								fetchTags(value);
							} */
						},
						helper: '选择所属的分类'
					},
				},
				tags: {
					title: '标签',
					search: { show: true },
					type: 'dict-select',
					column: {
						minWidth: 150,
						component: {
							// 自定义渲染组件，显示彩色标签
							name: 'fs-component',
							render: ({ row }: { row: any }) => {
								if (!row.tags || row.tags.length === 0) return <span>-</span>;
								
								return (
									<div style="display: flex; flex-wrap: wrap; gap: 4px;">
										{row.tags.map((tag: any) => (
											<el-tag
												key={tag.id}
												type="warning"
												effect="plain"
												size="mini"
											>
												{tag.name}
											</el-tag>
										))}
									</div>
								);
							}
						}
					},
					dict:  dict({
						// 使用API方式获取数据
						getData: async () => {
							const res = await api.GetTagList({page:1, limit:1000, tenant_id:1});
							return res.data.items;
						},
						label: 'name',
						value: 'id'
					}),
					form: {
						component: {
							props: {
								multiple: true,
								filterable: true,
								placeholder: '请选择标签'
							}
						},
						helper: '选择题目关联的标签，可多选'
					}
				},
				recommended_duration: {
					title: '建议时长(秒)',
					search: { show: false },
					column: {
						minWidth: 100,
					},
					form: {
						value: 60,
						component: {
							name: 'el-input-number',
							props: {
								min: 10,
								max: 600,
								step: 10
							}
						},
						helper: '建议回答此题目的时长，单位为秒'
					}
				},
				/* difficulty: {
					title: '难度等级',
					search: { show: true },
					type: 'dict-select',
					column: {
						minWidth: 80,
					},
					dict: dict({
						data: [
							{ value: 1, label: '初级' },
							{ value: 2, label: '中级' },
							{ value: 3, label: '高级' }
						]
					}),
					form: {
						rules: [{ required: true, message: '难度等级必填' }],
						helper: '选择题目的难度级别'
					},
				}, */
				is_system: {
					title: '系统题目',
					search: { show: false },
					type: 'dict-select',
					column: {
						width: 100,
						/* component: {
							name: 'fs-component',
							render: ({ row }: { row: any }) => {
								return row.is_system ? 
									<el-tag type="success" size="small">是</el-tag> : 
									<el-tag type="info" size="small">否</el-tag>;
							}
						} */
					},
					dict: dict({
						data: [
							{ value: true, label: '是' },
							{ value: false, label: '否' }
						]
					}),
					form: {
						value: false,
						component: {
							placeholder: '请选择是否为系统题目'
						},
						helper: '是否为系统预设题目'
					}
				},
				status: {
					title: '状态',
					search: { show: true },
					type: 'dict-select',
					column: {
						width: 80,
					},
					dict: dict({
						data: [
							{ value: 0, label: '停用' },
							{ value: 1, label: '启用' }
						]
					}),
					form: {
						value: 1,
						rules: [{ required: true, message: '状态必填' }],
						component: {
							placeholder: '请选择状态',
						},
						helper: '题目的启用状态'
					},
				},
				// 添加红线问题字段
				is_required_correct: {
					title: '红线问题',
					search: { show: true },
					type: 'dict-select',
					column: {
						width: 100,
						component: {
							name: 'fs-component',
							render: ({ row }: { row: any }) => {
								// 只有单选题和多选题才显示红线问题状态
								if (row.question_form !== 1 && row.question_form !== 2) {
									return <span>-</span>;
								}
								return row.is_required_correct ? 
									<el-tag type="danger" size="small">是</el-tag> : 
									<el-tag type="info" size="small">否</el-tag>;
							}
						}
					},
					dict: dict({
						data: [
							{ value: true, label: '是' },
							{ value: false, label: '否' }
						]
					}),
					form: {
						value: false,
						show: compute(({ form }) => {
							// 只有单选题和多选题才显示红线问题选项
							return form && (form.question_form === 1 || form.question_form === 2);
						}),
						component: {
							placeholder: '请选择是否为红线问题'
						},
						helper: '红线问题是指必须回答正确的题目，否则可能导致面试失败'
					}
				},
				sort: {
					title: '排序',
					search: { show: false },
					column: {
						width: 80,
					},
					form: {
						component: {
							name: 'el-input-number',
							props: {
								min: 1,
								max: 999
							}
						},
						helper: '题目的排序值，值越小排序越靠前'
					}
				},
				option_items: {
					title: '选项列表',
					search: { show: false },
					column: { show: false },
					form: {
						show: compute(({ form }) => {
							return form && (form.question_form === 1 || form.question_form === 2 || form.question_form === 4);
						}),
						component: {
							name: 'el-card',
							children: {
								default: ({ form }: { form: any }) => {
									// 确保options数组已初始化
									if (!form.options) {
										form.options = [];
									}
									
									// 心理评估题的选项渲染
									if (form.question_form === 4) {
										return (
											<div>
												<div class="option-header" style="display: flex; margin-bottom: 10px; font-weight: bold;">
													<span style="flex: 1;">选项内容</span>
													<span style="width: 120px; text-align: center;">分值</span>
												</div>
												{form.options.map((option: any, index: number) => (
													<div class="option-item" key={index} style="display: flex; align-items: center; margin-bottom: 10px;">
														<el-input 
															v-model={option.option_text} 
															placeholder="请输入选项内容" 
															style="flex: 1; margin-right: 10px;"
														/>
														<el-input-number
															v-model={option.score}
															min={0}
															max={10}
															style="width: 120px;"
															placeholder="分值"
														/>
													</div>
												))}
												<div style="display: flex; justify-content: space-between; margin-top: 10px;">
													<el-button 
														type="primary" 
														onClick={() => {
															if (!form.options) {
																form.options = [];
															}
															const sort = form.options.length > 0 ? 
																Math.max(...form.options.map((o: any) => o.sort || 0)) + 1 : 1;
															form.options.push({ option_text: '', score: 0, sort });
														}}
													>
														添加选项
													</el-button>
													
													{form.options.length > 2 && (
														<el-button 
															type="danger" 
															onClick={() => {
																form.options.pop();
															}}
														>
															删除最后一项
														</el-button>
													)}
												</div>
											</div>
										);
									}
									
									// 单选题和多选题的选项渲染（原有逻辑）
									return (
										<div>
											<div class="option-header" style="display: flex; margin-bottom: 10px; font-weight: bold;">
												<span style="flex: 1;">选项内容</span>
												<span style="width: 80px; text-align: center;">是否正确</span>
											</div>
											{form.options.map((option: any, index: number) => (
												<div class="option-item" key={index} style="display: flex; align-items: center; margin-bottom: 10px;">
													<el-input 
														v-model={option.option_text} 
														placeholder="请输入选项内容" 
														style="flex: 1; margin-right: 10px;"
													/>
													<el-tooltip 
														content="设置为正确答案" 
														placement="top" 
														effect="light"
													>
														<div 
															onClick={() => {
																if (form.question_form === 1) {
																	// 单选题：只能有一个正确答案
																	form.options.forEach((item: any, idx: number) => {
																		item.is_correct = (idx === index);
																	});
																} else {
																	// 多选题：可以有多个正确答案
																	option.is_correct = !option.is_correct;
																}
															}}
															style="cursor: pointer; width: 80px; text-align: center;"
														>
															{form.question_form === 1 ? (
																// 单选题使用单选按钮
																<el-radio 
																	modelValue={option.is_correct}
																	label={true}
																/>
															) : (
																// 多选题使用复选框
																<el-checkbox 
																	modelValue={option.is_correct}
																/>
															)}
														</div>
													</el-tooltip>
												</div>
											))}
											<div style="display: flex; justify-content: space-between; margin-top: 10px;">
												<el-button 
													type="primary" 
													onClick={() => {
														// 确保options数组已初始化
														if (!form.options) {
															form.options = [];
														}
														// 添加新选项时自动设置排序值
														const sort = form.options.length > 0 ? 
															Math.max(...form.options.map((o: any) => o.sort || 0)) + 1 : 1;
														form.options.push({ option_text: '', is_correct: false, sort });
													}}
												>
													添加选项
												</el-button>
												
												{form.options.length > 2 && (
													<el-button 
														type="danger" 
														onClick={() => {
															form.options.pop();
														}}
													>
														删除最后一项
													</el-button>
												)}
											</div>
										</div>
									)
								}
							}
						},
						helper: compute(({ form }) => {
							if (form.question_form === 1) {
								return '添加单选题的选项，并标记正确答案（只能有一个正确答案）';
							} else if (form.question_form === 2) {
								return '添加多选题的选项，并标记正确答案（可以有多个正确答案）';
							} else if (form.question_form === 4) {
								return '添加心理评估题的选项，并设置每个选项的分值';
							}
							return '';
						})
					}
				},
				scoring_reference: {
					title: '备注',
					search: { show: false },
					column: { show: false },
					form: {
						component: {
							name: 'el-input',
							type: 'textarea',
							rows: 4,
							placeholder: compute(({ form }) => {
								if (form && form.question_form === 4) {
									return '请输入评分标准说明';
								}
								return '请输入答案解析';
							})
						},
						helper: compute(({ form }) => {
							if (form && form.question_form === 4) {
								return '评分标准说明，例如：该评分反映了症状表现的频率与严重程度。';
							}
							return '题目的答案解析或备注信息';
						})
					},
				},
				
			},
			// 确保表格配置正确
			table: {
				selection: true,
				onSelectionChange: (selection: any[]) => {
					// 存储选中的行到一个全局变量中
					context.selectedRows = selection;
				},
			},
		},
	};
};

// 导出批量更新标签方法，供组件使用
export const useBatchUpdateTags = (crudExpose: any) => {
	const batchUpdateTags = async (questionIds: number[], tagIds: number[]) => {
		try {
			const res = await api.BatchUpdateTags({
				question_ids: questionIds,
				tag_ids: tagIds,
				tenant_id: 1
			});
			if (res.code === 0) {
				successMessage('批量更新标签成功');
				// 刷新列表
				crudExpose.doRefresh();
			}
		} catch (error) {
			console.error('批量更新标签失败', error);
		}
	};
	
	return { batchUpdateTags };
};

// 导出批量更新分类方法，供组件使用
export const useBatchUpdateCategory = (crudExpose: any) => {
	const batchUpdateCategory = async (questionIds: number[], categoryId: number) => {
		try {
			const res = await api.BatchUpdateCategory({
				question_ids: questionIds,
				category_id: categoryId,
				tenant_id: "1"
			});
			if (res.code === 0) {
				successMessage('批量更新分类成功');
				// 刷新列表
				crudExpose.doRefresh();
			}
		} catch (error) {
			console.error('批量更新分类失败', error);
		}
	};
	
	return { batchUpdateCategory };
};
